# Determine if systemd will be used
%if ( 0%{?fedora} && 0%{?fedora} > 16 ) || ( 0%{?rhel} && 0%{?rhel} > 6 )
%global with_systemd 1
%endif

%global selinuxtype targeted
%global moduletype  services
%global modulenames skyring

%global _format() export %1=""; for x in %{modulenames}; do %1+=%2; %1+=" "; done;
# Relabel files
%global skyring_relabel_files() %{_sbindir}/restorecon -R %{_bindir}/skyring %{_prefix}/lib/systemd/system/skyring.* /var/lib/skyring/.* /var/run/\.skyring-event /etc/skyring/ /var/log/skyring /etc/httpd &> /dev/null || :
%global salt_relabel_files() %{_sbindir}/restorecon -R %{_bindir}/salt* /etc/salt /var /var/cache/salt /var/log/salt /var/run/salt /srv/salt /usr/lib/systemd/system/salt* /usr/lib/systemd/system/salt-master /usr/bin/salt-minion /var/account/pacct /usr/bin/salt-master &> /dev/null || :
%global carbon_relabel_files() %{_sbindir}/restorecon -R %{_bindir}/carbon-aggregator %{_bindir}/carbon-cache %{_bindir}/carbon-client %{_bindir}/carbon-relay %{_bindir}/validate-storage-schemas %{_prefix}/lib/systemd/system/carbon* /var/lib/carbon/ /var/log/carbon/ /var/run/carbon-aggregator.pid /var/run/carbon-cache.pid &> /dev/null || :

# Version of distribution SELinux policy package
%if 0%{?fedora} >= 22
%global selinux_policyver 3.13.1-158.18
%endif
%if 0%{?fedora} >= 25
%global selinux_policyver 3.13.1-188
%endif
%if 0%{?rhel}
%global selinux_policyver 3.13.1-60
%endif

%define pkg_name skyring
%define pkg_version 0.0.41
%define pkg_release 1

Name: rhscon-core
Version: %{pkg_version}
Release: %{pkg_release}%{?dist}
Summary: Modern extensible web-based storage management platform
Source0: %{pkg_name}-%{pkg_version}.tar.gz
License: ASL 2.0
Group: Applications/System
BuildRoot: %{_tmppath}/%{pkg_name}-%{pkg_version}-%{pkg_release}-buildroot
Url: http://github.com/skyrings/skyring

%if 0%{?with_systemd}
BuildRequires: systemd
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/service
Requires(preun): /sbin/chkconfig
Requires(postun): /sbin/service
%endif

BuildRequires: golang
BuildRequires: python-devel
BuildRequires: python-setuptools
BuildRequires: openldap-devel

Requires: salt-master >= 2015.5.5
Requires: pytz
Requires: python-cpopen
Requires: python-netaddr
%if ( 0%{?fedora} && 0%{?fedora} > 16 )
Requires: mongodb-org
Requires: mongodb-org-server
%else
Requires: mongodb
Requires: mongodb-server
%endif
Requires: graphite-web
Requires: python-carbon
Requires: python-whisper
Requires: ceph-installer
Requires: mod_ssl
Requires: carbon-selinux
Requires: %{name}-selinux
Requires: salt-selinux

%description
SKYRING is a modern, extensible web-based storage management platform
which represents the future of storage management. SKYRING deploys,
manages and monitors various storage technologies and provides
a plugin framework for tomorrow’s SDS technologies.
SKYRING integrates best-of-breed open source components at its core,
and integrates with the broader management stack.

%package selinux
License: GPLv2
Group: System Environment/Base
Summary: SELinux Policies for Skyring
BuildArch: noarch
Requires(post): selinux-policy-base >= %{selinux_policyver}, selinux-policy-targeted >= %{selinux_policyver}, policycoreutils, policycoreutils-python libselinux-utils
BuildRequires: selinux-policy selinux-policy-devel

%description selinux
SELinux Policies for Skyring


%package -n salt-selinux
License: GPLv2
Group: System Environment/Base
Summary: SELinux Policies for Salt
BuildArch: noarch
Requires(post): selinux-policy-base >= %{selinux_policyver}, selinux-policy-targeted >= %{selinux_policyver}, policycoreutils, policycoreutils-python libselinux-utils
BuildRequires: selinux-policy selinux-policy-devel

%description -n salt-selinux
SELinux Policies for Salt


%package -n carbon-selinux
License: GPLv2
Group: System Environment/Base
Summary: SELinux Policies for Carbon
BuildArch: noarch
Requires(post): selinux-policy-base >= %{selinux_policyver}, selinux-policy-targeted >= %{selinux_policyver}, policycoreutils, policycoreutils-python libselinux-utils
BuildRequires: selinux-policy selinux-policy-devel

%description -n carbon-selinux
SELinux Policies for Carbon

%prep
%setup -n %{pkg_name}-%{pkg_version}

%build
make bzip-selinux-policies
make build-special
make pybuild

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
install -D skyring $RPM_BUILD_ROOT/usr/bin/skyring
install -Dm 0644 conf/sample/graphite-web.conf.sample $RPM_BUILD_ROOT/etc/skyring/httpd/conf.d/graphite-web.conf
install -DZm 0644 conf/sample/skyring-web.conf.sample $RPM_BUILD_ROOT/etc/httpd/conf.d/skyring-web.conf
install -Dm 0644 conf/sample/carbon.conf.sample $RPM_BUILD_ROOT/etc/skyring/carbon/carbon.conf
install -Dm 0644 conf/sample/storage-schemas.conf.sample $RPM_BUILD_ROOT/etc/skyring/carbon/storage-schemas.conf
install -m 755 -d $RPM_BUILD_ROOT/usr/share/skyring/setup
install -Dm 755 skyring-pre.sh $RPM_BUILD_ROOT/usr/bin/skyring-pre.sh
install -Dm 755 skyring-setup.sh $RPM_BUILD_ROOT%{_sbindir}/skyring-setup
install -Dm 0644 conf/sample/skyring_logrotate.conf.sample $RPM_BUILD_ROOT/etc/logrotate.d/%{name}
install -Dm 0644 conf/sample/skyring.conf.sample $RPM_BUILD_ROOT/etc/skyring/skyring.conf
install -Dm 0644 conf/sample/authentication.conf.sample $RPM_BUILD_ROOT/etc/skyring/authentication.conf
install -Dm 0644 conf/skyring_salt_master.conf $RPM_BUILD_ROOT/etc/salt/master.d/skyring.conf
install -Dm 0644 conf/sample/about.conf.sample $RPM_BUILD_ROOT/etc/skyring/about.conf
install -Dm 0644 event/skyring.evt $RPM_BUILD_ROOT/etc/skyring/skyring.evt
install -m 755 -d $RPM_BUILD_ROOT/srv/salt
install -m 755 -d $RPM_BUILD_ROOT/srv/salt/collectd
install -m 755 -d $RPM_BUILD_ROOT/srv/salt/template
install -m 755 -d $RPM_BUILD_ROOT/srv/salt/collectd/files
install -m 755 -d $RPM_BUILD_ROOT/var/log/skyring
install -Dm 0644 backend/salt/sls/*.* $RPM_BUILD_ROOT/srv/salt/
install -Dm 0644 backend/salt/sls/collectd/*.* $RPM_BUILD_ROOT/srv/salt/collectd
install -Dm 0644 backend/salt/conf/collectd/* $RPM_BUILD_ROOT/srv/salt/collectd/files
install -Dm 0755 backend/salt/template/* $RPM_BUILD_ROOT/srv/salt/template
install -d $RPM_BUILD_ROOT/%{python2_sitelib}/skyring
install -D backend/salt/python/skyring/* $RPM_BUILD_ROOT/%{python2_sitelib}/skyring/
install -D -p -m 0644 misc/systemd/%{pkg_name}.service %{buildroot}%{_unitdir}/%{pkg_name}.service
install -p -D -m 644 misc/systemd/%{pkg_name}.sysconf  %{buildroot}%{_sysconfdir}/sysconfig/%{pkg_name}
install -m 755 -d $RPM_BUILD_ROOT/srv/salt/_modules
install -Dm 0644 salt_module/skyring_utils.py $RPM_BUILD_ROOT/srv/salt/_modules
install -Dm 0644 salt_module/collectd.py $RPM_BUILD_ROOT/srv/salt/_modules
gzip skyring.8
install -Dm 0644 skyring.8.gz $RPM_BUILD_ROOT%{_mandir}/man8/skyring.8.gz
chmod -x $RPM_BUILD_ROOT/%{python2_sitelib}/skyring/__init__.py
chmod -x $RPM_BUILD_ROOT/%{python2_sitelib}/skyring/saltwrapper.py
chmod +x $RPM_BUILD_ROOT/srv/salt/push_event.sls

# Install SELinux interfaces and policy modules
install -d %{buildroot}%{_datadir}/selinux/devel/include/%{moduletype}
install -d %{buildroot}%{_datadir}/selinux/packages

# skyring
install -p -m 644 selinux/skyring.if \
	%{buildroot}%{_datadir}/selinux/devel/include/%{moduletype}
install -m 0644 selinux/skyring.pp.bz2 \
	%{buildroot}%{_datadir}/selinux/packages

# salt
install -p -m 644 selinux/salt.if \
	%{buildroot}%{_datadir}/selinux/devel/include/%{moduletype}
install -m 0644 selinux/salt.pp.bz2 \
	%{buildroot}%{_datadir}/selinux/packages

# carbon
install -p -m 644 selinux/carbon.if \
	%{buildroot}%{_datadir}/selinux/devel/include/%{moduletype}
install -m 0644 selinux/carbon.pp.bz2 \
	%{buildroot}%{_datadir}/selinux/packages

%post
/bin/systemctl enable skyring.service >/dev/null 2>&1 || :

%post selinux
%_format MODULE %{_datadir}/selinux/packages/skyring.pp.bz2
%{_sbindir}/semodule -n -s %{selinuxtype} -i $MODULE
if %{_sbindir}/selinuxenabled ; then
    %{_sbindir}/load_policy
    %skyring_relabel_files
fi

semanage port -a -t mailbox_port_t -p tcp 2004 2> /dev/null
semanage port -a -t xinuexpansion4_port_t -p tcp 2024 2> /dev/null
semanage port -a -t xinuexpansion5_port_t -p tcp 2004 2> /dev/null
semanage port -a -t xinuexpansion3_port_t -p tcp 2023 2> /dev/null
semanage boolean -m collectd_tcp_network_connect --on
setsebool -P httpd_can_network_connect on
semanage port -a -p tcp -t afs_pt_port_t 7002 2> /dev/null || :

%post -n salt-selinux
%_format MODULE %{_datadir}/selinux/packages/salt.pp.bz2
%{_sbindir}/semodule -n -s %{selinuxtype} -i $MODULE
if %{_sbindir}/selinuxenabled ; then
    %{_sbindir}/load_policy
    %salt_relabel_files
fi

%post -n carbon-selinux
%_format MODULE %{_datadir}/selinux/packages/carbon.pp.bz2
%{_sbindir}/semodule -n -s %{selinuxtype} -i $MODULE
if %{_sbindir}/selinuxenabled ; then
    %{_sbindir}/load_policy
    %carbon_relabel_files
fi

%postun selinux
if [ $1 -eq 0 ]; then
    %{_sbindir}/semodule -n -r %{modulenames} &> /dev/null || :
    if %{_sbindir}/selinuxenabled ; then
	%{_sbindir}/load_policy
	%skyring_relabel_files
    fi
fi

%postun -n salt-selinux
if [ $1 -eq 0 ]; then
    %{_sbindir}/semodule -n -r %{modulenames} &> /dev/null || :
    if %{_sbindir}/selinuxenabled ; then
	%{_sbindir}/load_policy
	%salt_relabel_files
    fi
fi

%postun -n carbon-selinux
if [ $1 -eq 0 ]; then
    %{_sbindir}/semodule -n -r %{modulenames} &> /dev/null || :
    if %{_sbindir}/selinuxenabled ; then
	%{_sbindir}/load_policy
	%carbon_relabel_files
    fi
fi

%postun
if [ -e /etc/httpd/conf.d/graphite-web.conf.orig -a -h /etc/httpd/conf.d/graphite-web.conf -a ! -e "`readlink /etc/httpd/conf.d/graphite-web.conf`" ] ; then
 mv -f /etc/httpd/conf.d/graphite-web.conf.orig /etc/httpd/conf.d/graphite-web.conf
fi
if [ -e /etc/carbon/carbon.conf.orig -a -h /etc/carbon/carbon.conf -a ! -e "`readlink /etc/carbon/carbon.conf`" ] ; then
 mv -f /etc/carbon/carbon.conf.orig /etc/carbon/carbon.conf
fi
if [ -e /etc/carbon/storage-schemas.conf.orig -a -h /etc/carbon/storage-schemas.conf -a ! -e "`readlink /etc/carbon/storage-schemas.conf`" ] ; then
 mv -f /etc/carbon/storage-schemas.conf.orig /etc/carbon/storage-schemas.conf
fi
rm -f /etc/logrotate.d/%{name}


%triggerin -- graphite-web
if [ ! -h /etc/httpd/conf.d/graphite-web.conf -o ! "`readlink /etc/httpd/conf.d/graphite-web.conf`" = "/etc/skyring/httpd/conf.d/graphite-web.conf" ] ; then
  if [ -e /etc/httpd/conf.d/graphite-web.conf ] ; then
    mv -f /etc/httpd/conf.d/graphite-web.conf /etc/httpd/conf.d/graphite-web.conf.orig
  fi
  ln -s /etc/skyring/httpd/conf.d/graphite-web.conf /etc/httpd/conf.d/graphite-web.conf
fi
if [ ! -h /etc/carbon/carbon.conf -o ! "`readlink /etc/carbon/carbon.conf`" = "/etc/skyring/carbon/carbon.conf" ] ; then
  if [ -e /etc/carbon/carbon.conf ] ; then
    mv -f /etc/carbon/carbon.conf /etc/carbon/carbon.conf.orig
  fi
  ln -s /etc/skyring/carbon/carbon.conf /etc/carbon/carbon.conf
fi
if [ ! -h /etc/carbon/storage-schemas.conf -o ! "`readlink /etc/carbon/storage-schemas.conf`" = "/etc/skyring/carbon/storage-schemas.conf" ] ; then
  if [ -e /etc/carbon/storage-schemas.conf ] ; then
    mv -f /etc/carbon/storage-schemas.conf /etc/carbon/storage-schemas.conf.orig
  fi
  ln -s /etc/skyring/carbon/storage-schemas.conf /etc/carbon/storage-schemas.conf
fi

%triggerun -- graphite-web
if [ ! -h /etc/httpd/conf.d/graphite-web.conf -o ! "`readlink /etc/httpd/conf.d/graphite-web.conf`" = "/etc/skyring/httpd/conf.d/graphite-web.conf" ] ; then
  if [ -e /etc/httpd/conf.d/graphite-web.conf ] ; then
    mv -f /etc/httpd/conf.d/graphite-web.conf /etc/httpd/conf.d/graphite-web.conf.orig
  fi
  ln -s /etc/skyring/httpd/conf.d/graphite-web.conf /etc/httpd/conf.d/graphite-web.conf
fi
if [ ! -h /etc/carbon/carbon.conf -o ! "`readlink /etc/carbon/carbon.conf`" = "/etc/skyring/carbon/carbon.conf" ] ; then
  if [ -e /etc/carbon/carbon.conf ] ; then
    mv -f /etc/carbon/carbon.conf /etc/carbon/carbon.conf.orig
  fi
  ln -s /etc/skyring/carbon/carbon.conf /etc/carbon/carbon.conf
fi
if [ ! -h /etc/carbon/storage-schemas.conf -o ! "`readlink /etc/carbon/storage-schemas.conf`" = "/etc/skyring/carbon/storage-schemas.conf" ] ; then
  if [ -e /etc/carbon/storage-schemas.conf ] ; then
    mv -f /etc/carbon/storage-schemas.conf /etc/carbon/storage-schemas.conf.orig
  fi
  ln -s /etc/skyring/carbon/storage-schemas.conf /etc/carbon/storage-schemas.conf
fi

%triggerpostun -- graphite-web
if [ $2 -eq 0 ] ; then
 rm -f /etc/httpd/conf.d/graphite-web.conf.rpmsave /etc/httpd/conf.d/graphite-web.conf.orig
fi
if [ -e /etc/httpd/conf.d/graphite-web.conf.rpmnew ] ; then
 mv /etc/httpd/conf.d/graphite-web.conf.rpmnew /etc/httpd/conf.d/graphite-web.conf.orig
fi
if [ $2 -eq 0 ] ; then
 rm -f /etc/carbon/carbon.conf.rpmsave /etc/carbon/carbon.conf.orig
fi
if [ -e /etc/carbon/carbon.conf.rpmnew ] ; then
 mv /etc/carbon/carbon.conf.rpmnew /etc/carbon/carbon.conf.orig
fi
if [ $2 -eq 0 ] ; then
 rm -f /etc/carbon/storage-schemas.conf.rpmsave /etc/carbon/storage-schemas.conf.orig
fi
if [ -e /etc/carbon/storage-schemas.conf.rpmnew ] ; then
 mv /etc/carbon/storage-schemas.conf.rpmnew /etc/carbon/storage-schemas.conf.orig
fi

%clean
rm -rf "$RPM_BUILD_ROOT"

%files selinux
%defattr(-,root,root,0755)
%attr(0644,root,root) %{_datadir}/selinux/packages/skyring.pp.bz2
%attr(0644,root,root) %{_datadir}/selinux/devel/include/%{moduletype}/skyring.if

%files -n salt-selinux
%defattr(-,root,root,0755)
%attr(0644,root,root) %{_datadir}/selinux/packages/salt.pp.bz2
%attr(0644,root,root) %{_datadir}/selinux/devel/include/%{moduletype}/salt.if

%files -n carbon-selinux
%defattr(-,root,root,0755)
%attr(0644,root,root) %{_datadir}/selinux/packages/carbon.pp.bz2
%attr(0644,root,root) %{_datadir}/selinux/devel/include/%{moduletype}/carbon.if

%files
%attr(0755, root, root) /usr/bin/skyring
%attr(0755, root, root) /usr/bin/skyring-pre.sh
%attr(0755, root, root) %{_sbindir}/skyring-setup
%{python2_sitelib}/skyring/*
%{_var}/log/skyring
/srv/salt/*
%{_unitdir}/%{pkg_name}.service
%config(noreplace) %{_sysconfdir}/sysconfig/%{pkg_name}
%config(noreplace) %attr(644,root,root) %{_sysconfdir}/skyring/httpd/conf.d/graphite-web.conf
%config(noreplace) %attr(644,root,root) %{_sysconfdir}/httpd/conf.d/skyring-web.conf
%config(noreplace) %attr(644,root,root) %{_sysconfdir}/skyring/carbon/carbon.conf
%config(noreplace) %attr(644,root,root) %{_sysconfdir}/skyring/carbon/storage-schemas.conf
%config(noreplace) %{_sysconfdir}/skyring/authentication.conf
%config(noreplace) %{_sysconfdir}/skyring/skyring.conf
%config(noreplace) %{_sysconfdir}/salt/master.d/skyring.conf
%config(noreplace) %{_sysconfdir}/skyring/about.conf
%config(noreplace) %{_sysconfdir}/skyring/skyring.evt
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%doc README.md
%{_mandir}/man8/skyring.8.gz

%changelog
* Fri Aug 05 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.41-1
- Changes
  - Stable build v0.0.41-1

* Fri Aug 05 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.40-1
- Changes
  - Generate unique password for mongodb admin during installation
  - Set auth = true post installation for mongodb
  - Encode and send configurations to provider
  - selinux - Allow collectd to access dmidecode and dmesg
  - Moved selinux to permissive for salt_t and skyring_t

* Mon Aug 01 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.39-1
- Changes
  - Enahnced logging for monitoring

* Thu Jul 28 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.38-1
- Changes
  - Build due to change in skyring-common package

* Wed Jul 27 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.37-1
- Changes
  - Added additional check while timing out a task
  - Fixed collectd configuration on ubuntu
  - Modified disk size as float64
  - Changed the task explicit stop message

* Fri Jul 22 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.36-1
- Changes
  - Modified status filter for cluster listing API
  - Handle monitoring schedule while cluster unmanage/manage

* Wed Jul 20 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.35-1
- Changes
  - Sync summaries after entity creation
  - Update stats to graphite only if data available
  - Corrected makefile
  - Fixed rpmlint issue "E: incoherent-logrotate-file /etc/logrotate.d/skyring"
  - Removed displaying default mongodb credentials post setup
  - Sync node utilizations clean up
  - selinux - allow skyring to access /var directory

* Wed Jul 13 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.34-1
- Changes
  - selinux - fixed mislabeled config files copied after package installation
  - Disabled negroni logging
  - selinux - fixed carbon-cache restart issue in selinux enabled

* Tue Jul 12 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.33-1
- Changes
  - selinux - allow salt-call to access dmidecode, dmesg and other details
  - corrected mislabelled skyring-web.conf
  - corrected the link creation for skyring-setup.sh
  - cleanup in skyring.spec file
  - corrected cluster expansion case monitoring configuration
  - forward node down event to provider to take action

* Fri Jul 08 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.32-1
- Changes
  - Dismiss all alerts when an entity is deleted
  - Update alarm count when user dismisses an event
  - Use systemd command in setup script
  - TLS certificate usability improvements in setup script
  - Corrected TLS certificate path and permissions
  - Rename storage profile general to default

* Tue Jul 05 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.31-1
- Changes
  - Create mongodb user while starting service
  - selinux - allow collectd to collect node details
  - Fixed scriptlet failed error while skyring-selinux package installation
  - selinux - allow collectd to tcp network connect

* Fri Jul 01 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.30-1
- Changes
  - Code cleanup related to db session creation
  - Fixed event name for mount point utilization event
  - Modified to check if PKNAME available while getting disk details

* Tue Jun 28 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.29-1
- Changes
  - Stop disabling firewalld during skyring-setup

* Fri Jun 24 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.28-1
- Changes
  - Fixed event handling for node hardware related events

* Fri Jun 24 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.27-1
- Changes
  - Mark correct cluster state while create cluster task failure / timeout
  - Fixed an issue while logging errors in salt log files
  - Enable collectd and httpd services while node initialization
  - Service URLs in summary section of setup script

* Mon Jun 20 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.26-1
- Changes
  - Rebuild due to common project changes

* Sat Jun 18 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.25-1
- Changes
  - Added last updated time to utilizations and summary
  - Added force sync apis for summary
  - Dont consider the disk if size blank while disk sync for node
  - Configure options for skyring service
  - Updated selinux policy for fedora and rhel

* Tue Jun 14 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.24-1
- Changes
  - Add node services list from node to summary
  - Update node service state when it changes

* Mon Jun 13 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.23-1
- Changes
  - Re-set cluster state as active if sync fails
  - Enabled syncing of block devices while master sync
  - Force sync summary after cluster expansion and import
  - Utilization fetch from graphite
  - Ask for server FQDN while setup
  - Added sample carbon configurations

* Tue Jun 07 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.22-1
- Changes
  - selinux policies enabled for skyring and salt packages
  - ldap related fixes
  - URL re-direct for http to https. https would be by default enabled now
  - import user without email address
  - added api for disk hierarchy listing
  - fixes around log rotate feature
  - monitoring configurations in summary api
  - ldap - corrected static initialization
  - refined task filter conditions

* Mon May 30 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.21-1
- Changes
  - Metric collection from collectd, set timeout as 5 mins
  - Corrected monitoring configuration while import cluster

* Fri May 27 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.20-1
- Changes
  - Increased node physical resources sync interval to 5 mins
  - Salt client creation made local (performance improvement)
  - Device type correction while fetch
  - selinux mode correction while fetch

* Fri May 20 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.19-1
- Changes
  - Monitoring sw details in about api
  - Additional filters for clusters, SLUs and storages list
  - Corrected initialization of mgo sessions
  - Grouped system utilizations for monitoring
  - Near full computations and monitoring for clusters, SLUs
  - Modified salt job flush time to 1 hour
  - Few fixes around monitoring framework

* Mon May 16 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.18-1
- Changes
  - Refresh mongodb session
  - Event listing api refined
  - cluster and node list filtering based on alarm status
  - enabled websocket broadcast in SSL mode

* Wed May 11 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.17-1
- Changes
  - Filter clusters list based on status and role
  - Filter storages list based on status
  - Filter nodes list based on status and role
  - Fixed an issue with skyring-setup.sh

* Fri May 06 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.16-1
- Changes
  - Enabled log rotation
  - Sync network utilization
  - Enabled monitoring for an imported cluster
  - Enabled SSL mode for skyring
  - Mark creating cluster as failed while restart of skyring
  - Timeout node initialization if not responding for 10 minutes
  - BZ#1333775

* Wed May 04 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.15-1
* Changes
  - Enabled logging of provisioner task details

* Sat Apr 30 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.14-1
- Changes
  - Added import cluster feature
  - Modified salt configuration for calamari events

* Fri Apr 29 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.13-1
- Changes
  - Archive old task and event details
  - Fixed routing of calamari events
  - Configure UNIXSOC collectd plugin
  - Added utilizations to summary apis
  - Updated to get instant statistics from collectd directly

* Fri Apr 22 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.12-1
- Changes
  - Update alarm count and status on receiving events
  - remove host by name api
  - change password option for user
  - rpmlint fixes
  - Event type definitions externalization
  - Alert aggregation for events
  - aggregate network interface and iops at node level
  - node storage utilization
  - audit log changes
  - list slus as well in listing storages
  - node summary api
  - journal support while create cluster
  - Make file changes
  - Made skyring a systemd service

* Tue Mar 29 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.11-1
- Changes
  - Corrected skyring.conf sample file

* Tue Mar 29 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.10-2
- Changes
  - Corrected release no

* Tue Mar 29 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.10-2
- Changes
  - Changed the name of ceph installer component

* Tue Mar 29 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.10-1
- Changes
  - Removed locking of nodes while storage creation
  - Cluster sync jobs
  - cpu and memory instant values for nodes
  - warning thresholds for physical resources
  - Threshold monitoring changes

* Thu Mar 24 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.9-1
- Changes
  - API for cluster config details
  - API for about page
  - setup script cleanup
  - API for editing storage entity
  - Ignore recovery events if original event not found

* Wed Mar 16 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.8-14
- Changes
  - Clear alerts on recovery events
  - Severity of audit log events changed
  - Added package installation during expand cluster flow
  - Added redhat-ceph-installer as dependency

* Tue Mar 15 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.8-13
- Changes
  - ceph-installer integration
  - Force stop the tasks not responding for long
  - Re-initialize the in progress nodes on restart
  - Mark the incomplete tasks as stopped on restart
  - System monitoring stats

* Fri Mar 11 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.8-12
- Changes
  - CPU, latency aggregation
  - Network throughput aggregation
  - iops and network throughput aggregation
  - Configure n/w latency plugin
  - Event handling for swap, memory, cpu and mount point utlization

* Mon Mar 07 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.8-11
- Changes
  - Enabled travis ci builds
  - Provisioning framework
  - Cluster summary
  - Logical resources count
  - Disk iops monitoring

* Tue Mar 01 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.8-10
- Updated new tarball

* Tue Mar 01 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.8-9
- Changes
  - Added memory usage percentage
  - Enhanced event listing api
  - New PATCH api for events
  - Enabled filtering of tasks

* Mon Feb 29 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.8-8
- Changes
  - Re-initialize node
  - Block device management api create/delete/resize/list
  - Delete storage api
  - OSD status/state
  - New event model
  - Pagination in event listing
  - Enhacements in monitoring

* Wed Feb 24 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.8-7
- Corrected salt reactor details

* Tue Feb 23 2016 Shubhendu Tripath <shtripat@redhat.com> - 0.0.8.6
- Changes
  - Node and cluster status/state changes
  - Add un-accepted node through events
  - Cluster level monitoring summary
  - Auto expand cluster on disk additions to nodes
  - Few fixes

* Wed Feb 17 2016 Timothy Asir <tjeyasin@redhat.com> - 0.0.8-5
- Changes
  - External user search and pagination
  - Moved ldap configuration to db

* Tue Feb 16 2016 Shubhendu Tripath <shtripat@redhat.com> - 0.0.8-4
- Corrected an issue with salt reactor configuration

* Mon Feb 15 2016 Timothy Asir <tjeyasin@redhat.com> - 0.0.8-3
- Changes
  - Introduced common module skyring-common
  - Taskified node delete apis
  - Feature to rollback monitoring configuration
  - BZ# 1299468
  - Query for cluster statistics
  - Introduced different cluster states
  - Context in log messages
  - Pagination support for tasks listing
  - Mail notification enabled in framework
  - Sync salt modules during accept nodes
  - Added graphite dependencies for monitoring
  - Logical resources monitoring like slu, storage pfoiles etc

* Tue Feb 02 2016 Timothy Asir <tjeyasin@redhat.com> -  0.0.8-2
- Changes
  - BZ#1296123, BZ#1298977, BZ#1299005, BZ#1296464, BZ#1302335, BZ#1302328
  - Fixed issues in import users from external users list
  - Auto apply storage profile
  - Scheduling framework
  - Event based accept node
  - Code stabilization

* Thu Jan 28 2016 Shubhendu Tripathi <shtripat@redhat.com> - 0.0.8-1
- Added below features -
  - Locking framework
  - Update pgnum.pgpgnum for cluster expand scenario
  - Replaced influxdb with graphite for monitoring DB
  - Fix in gopy to check for exception and clear
  - Daemonize the project
  - Few bug fixes and code refactors

* Fri Jan 22 2016 Timothy Asir <tjeyasin@redhat.com> - 0.0.7-0.1.alpha1
- Build alpha1 - v0.0.7-0.1.alpha1 (code refresh)

* Fri Jan 08 2016 Kanagaraj Mayilsamy <kmayilsa@redhat.com> - 0.0.6-0.1.alpha1
- Build alpha1 - v0.0.6-0.1.alpha1

* Tue Jan 05 2016 Kanagaraj Mayilsamy <kmayilsa@redhat.com> - 0.0.5-0.1.alpha1
- Build alpha1 - v0.0.5-0.1.alpha1

* Thu Dec 31 2015 Kanagaraj Mayilsamy <kmayilsa@redhat.com> - 0.0.4-0.1.alpha1
- Build alpha1 - v0.0.4-0.1.alpha1

* Wed Dec 30 2015 Kanagaraj Mayilsamy <kmayilsa@redhat.com> - 0.0.3-1
- Rebuild v0.0.3

* Thu Dec 24 2015 Kanagaraj Mayilsamy <kmayilsa@redhat.com> - 0.0.2-1
- Fix package dependencies

* Thu Dec 03 2015 Timothy Asir Jeyasingh <tjeyasin@redhat.com> 0.0.1
- Initial build.
